@@ -154,7 +154,7 @@ class backgrounds(TemplateFormat):
         if self.convert not in self.objVar.Get('cl_image_formats'):
             self.setError(_("Wrong image format '%s'") % self.convert)
             return False
-        reRule = re.compile("^(\d+)x(\d+)$")
+        reRule = re.compile("^(\d+)x(\d+)(?:-[0-9]+)?$")
         if not rootPath:
             rootPath = '/'
 
