@@ -34,6 +34,17 @@ MINUTES = 60
 HOURS = 60 * MINUTES
 DAYS = 24 * HOURS
 
+def _urlopen(fn, timeout=None):
+    """
+    Получить URL, без прокси
+    """
+    proxy_handler = urllib2.ProxyHandler({})
+    opener = urllib2.build_opener(proxy_handler)
+    if timeout is not None:
+        return opener.open(fn, timeout=timeout)
+    else:
+        return opener.open(fn)
+
 
 class BinhostsBase(object):
     class BinhostStatus:
@@ -57,7 +68,7 @@ class BinhostsBase(object):
 
     def check_package_timestamp(self, fn, timestamp):
         for i, line in enumerate(
-                urllib2.urlopen(fn, timeout=self.timeout)):
+                _urlopen(fn, timeout=self.timeout)):
             if line.startswith("TIMESTAMP"):
                 return str(timestamp) == line.rpartition(":")[2].strip()
             if i > 50:
@@ -73,7 +84,7 @@ class BinhostsBase(object):
             try:
                 for fn in revision_files:
                     base_dn = path.dirname(fn)
-                    data = urllib2.urlopen(fn, timeout=self.timeout).read()
+                    data = _urlopen(fn, timeout=self.timeout).read()
                     cp = ConfigParserCaseSens()
                     if data:
                         try:
@@ -111,7 +122,7 @@ class BinhostsBase(object):
         timestamp_file = path.join(binhost, self.ts_path)
         try:
             t = time.time()
-            data = urllib2.urlopen(timestamp_file,
+            data = _urlopen(timestamp_file,
                                    timeout=self.timeout).read().strip()
             if data.isdigit() and self.last_ts.isdigit():
                 return (data, int((time.time() - t) * 1000),
@@ -225,7 +236,7 @@ def fetch_packages(url_binhost, cache_fn, timeout=300, ttl=30 * DAYS):
     for uri in ("Packages.xz", "Packages"):
         fn = path.join(url_binhost, uri)
         try:
-            data = urllib2.urlopen(fn, timeout=timeout).read()
+            data = _urlopen(fn, timeout=timeout).read()
             if uri == "Packages.xz":
                 data = xz(data, decompress=True)
                 break
