@@ -18,6 +18,7 @@ import select
 import random
 import shutil
 import string
+from hashlib import sha256
 
 import os
 from os import path
@@ -1634,3 +1635,19 @@ def xztaropen(fn):
     finally:
         if f:
             f.close()
+
+def sha256sum(*fns):
+    """
+    Вычислить контрольную сумму у перечисленных файлов
+    :param fns:
+    :return:
+    """
+    kb = 1024
+    hasher = sha256()
+    for fn in fns:
+        with open(fn) as f:
+            b = True
+            while b:
+                b = f.read(512 * kb)
+                hasher.update(b)
+    return hasher.hexdigest()
